@@ -6,4 +6,7 @@ class RedditApiError(MemeLibExeception):
     pass
 class SubredditNotFoundError(RedditApiError):
     """That subreddit wasn't found"""
+    pass
+class RateLimitError(RedditApiError):
+    """The Reddit API returned 429"""
     pass
\ No newline at end of file
